@@ -1,12 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2004 Peter Simonsson <psn@linux.se>
+    SPDX-FileCopyrightText: 2004 Peter Simonsson <psn@linux.se>
 */
 
 #ifndef KONVERSATIONJOINCHANNELDIALOG_H
@@ -28,25 +23,29 @@ namespace Konversation
     {
         Q_OBJECT
             public:
-            explicit JoinChannelDialog(Server* server, QWidget *parent = 0);
-            ~JoinChannelDialog() override;
+            explicit JoinChannelDialog(Server* server, QWidget *parent = nullptr);
+            ~JoinChannelDialog();
 
             int connectionId() const;
             QString channel() const;
             QString password() const;
 
-        protected Q_SLOTS:
-            virtual void slotOk();
+        private Q_SLOTS:
+            void slotOk();
             void slotNicknameChanged(const QString& nickname);
             void slotConnectionListChanged();
             void slotSelectedConnectionChanged(int);
             void slotChannelChanged(const QString& text);
             void slotChannelHistoryCleared();
+            void deleteChannel();
 
         private:
             Ui::JoinChannelUI m_ui;
             QPushButton *mOkButton;
+
+            Q_DISABLE_COPY(JoinChannelDialog)
     };
 
 }
+
 #endif
